// index.js
import { showToast, randomString } from '../../util/util'

// 获取应用实例
const app = getApp()

Page({
  data: {
    // 参数列表
    plateNumber: randomString(6),
    plateColor: 'BLUE',
    startTime: '2021-07-22T10:43:39+08:00',
    parkingName: '欢乐海岸停车场',

    // 状态列表
    parking: false,

    // 身份认证信息
    openid: '',
  },
  onLoad() {
    this.login()
  },
  beginParking() {
    console.log(`parking: ${this.data.parking}`)
    if (this.data.parking) {
      return
    }
    wx.request({
      url: `${app.globalData.serverDomain}/parking`,
      method: 'POST',
      dataType: 'json',
      data: {
        plate_number: `测${this.data.plateNumber}`,
        plate_color: this.data.plateColor,
        start_time: this.data.startTime,
        parking_name: this.data.parkingName
      },
      success: (res) => {
        if (res.statusCode === 200) {
          showToast('创建停车入场成功')
          this.setData({
            parking: true,
          })
        } else if (res.statusCode === 403) {
          // 用户目前无法使用支付分停车服务
          console.error(`${res.data?.code}: ${res.data?.message}`)
          switch (res.data?.details?.reason) {
            case 'OUT_SERVICE':
              this.askToSignInCreditParking(); break
            case 'OVERDUE':
              showToast('当前用户处于欠费状态，请先缴清相关款项'); break
            case 'PAUSE':
              showToast('当前用户已暂停微信支付分停车服务'); break
            case 'EVALUATION_FAILED':
              showToast('当前用户综合评估未通过，不可使用支付分停车服务'); break
            default:
              break
          } 
        } else if (res.statusCode === 400) {
          showToast('已经停车入场成功，无需再次操作！')
        } else {
          console.error(res)
          showToast(`创建停车入场失败：${res.statusCode}`)
        }
      },
      fail: (err) => {
        console.error(`fail to create parking: ${err}`)
        showToast(`创建停车入场失败：${err.errMsg}`)
      },
      complete: () => {
        console.log(`parking: ${this.data.parking}`)
      }
    })
  },
  stopParking() {
    console.log(`parking: ${this.data.parking}`)
    if (!this.data.parking) {
      return
    }
    wx.request({
      url: `${app.globalData.serverDomain}/parking`,
      method: 'PUT',
      dataType: 'json',
      data: {
        plate_number: `测${this.data.plateNumber}`,
        plate_color: this.data.plateColor,
        start_time: this.data.startTime,
        parking_name: this.data.parkingName
      },
      success: (res) => {
        if (res.statusCode === 200) {
          this.setData({
            parking: false,
          })
          showToast('停车出场扣费成功')
        } else if (res.statusCode === 400) {
          console.error(res.data)
          this.askToSignInCreditParking()
        } else {
          console.error(`fail to stop parking: ${res.statusCode}`)
        }
      },
      fail: (err) => {
        console.error(`fail to stop parking: ${err}`)
      },
      complete: () => {
        console.log(`parking: ${this.data.parking}`)
      }
    })
  },
  login() {
    if (this.data.openid) {
      return
    }
    wx.login({
      success: (res) => {
        if (res.code) {
          console.log(res.code)
          wx.request({
            url: `${app.globalData.serverDomain}/login`,
            method: 'POST',
            dataType: 'json',
            data: {
              code: res.code
            },
            success: (res) => {
              if (res.data) {
                console.log(res.data)
                this.setData({
                  openid: res.data?.openid
                })
              } else {
                console.error('fail to get openid')
              }
            }
          })
        }
      }
    })
  },
  askToSignInCreditParking() {
    wx.showModal({
      title: '当前车牌未开通微信支付分，是否开通？',
      success: (res) => {
        if (res.confirm) {
            wx.navigateToMiniProgram({
              appId: 'wxbcad394b3d99dac9', // 车主服务小程序 appid
              path: '/pages/auth-creditpay/auth-creditpay', // 车主服务小程序支付分停车开通页
              extraData: {
                plate_number: `测${this.data.plateNumber}`,
                plate_color: this.data.plateColor,
                openid: this.data.openid,
                mchid: app.globalData.mchid,
                trade_scene: 'PARKING'
              },
              fail: (err) => {
                console.error(`fail to navigate to mini-program: ${err}`)
              },
            })
        } else {
          showToast('欢迎下次体验微信支付分停车服务^_^')
        }
      },
    })
  },
})
