# 微信支付分停车服务示例代码 — Go 服务端

本示例代码基于 Go 语言和 `net/http` 包编写，用于运行一个接入微信支付分停车服务的业务服务端。



## 环境要求

为顺利运行支持分停车服务的 Go 服务端示例代码，您需要准备以下环境：

- [Go](https://golang.org/doc/install) 版本至少为 1.11（支持 Go Module）

- 可通过 HTTPS 协议访问的网站（用于接收来自微信支付的回调，若部署在本地则无法使用回调功能）
- 网站服务器安装了 Go（版本至少为 1.11）、Nginx（用于反向代理）



## 运行

### 配置环境变量

将示例代码根目录中的 `.env.example` 文件复制到当前目录中，并命名为 `.env`，然后填入商户号、平台证书序列号等信息。

```shell
cp ../../.env.example .env
```

```shell
# 商户号
WXPAY_MERCHANT_ID=
# 商户证书序列号
WXPAY_MERCHANT_CERTIFICATE_SERIAL_NUMBER=
# 商户 APIv3 密钥
WXPAY_MERCHANT_APIV3_KEY=
# 商户绑定的 appid
WXPAY_MERCHANT_APP_ID=
# 商户绑定 appid 对应的 appsecret
WXPAY_MERCHANT_APP_SECRET=
# 商户证书私钥文件路径
WXPAY_MERCHANT_PRIVATE_KEY_PATH=

# 当前 demo 服务部署的 URL，若需要使用回调功能，需要修改为服务器部署地址，如 https://www.my-website.com/credit-parking-demo
DOMAIN=http://localhost:8080
```

### 本地测试

在当前目录下运行程序，示例代码将会运行在 `http://localhost:8080` 路径，此时您可以与小程序联调，但无法正常使用回调功能（用户车辆服务状态更新及扣款结果更新会受到影响）

```
go run main.go
```

此时访问 `http://localhost:8080` 我们应该能看到页面显示“你好，微信支付分停车服务！”。

### 部署

若需要测试回调功能，则需要将示例代码部署到可通过 HTTPS 协议访问的网站中。

具体部署方式请根据商户后台系统的部署流程确定，此处给出一种部署示例的代码的示例脚本（可在本地灵活启动或停止示例代码服务）

```shell
WCP_DEPLOY_USER=
WCP_DEPLOY_HOST=

find . -not -path '*git*' \
| xargs tar cf - \
| ssh ${WCP_DEPLOY_USER}@${WCP_DEPLOY_HOST} 'rm -rf /tmp/wxpay-credit-parking-demo \
    && mkdir -p /tmp/wxpay-credit-parking-demo \
    && tar xf - -C /tmp/wxpay-credit-parking-demo \
    && cd /tmp/wxpay-credit-parking-demo \
    && /usr/local/go/bin/go build \
    && killall -9 credit-parking-demo || echo "credit parking demo is not running" \
    && ./credit-parking-demo'
```

通过以上步骤，示例代码服务将运行在网站服务器中，我们还需要将其映射到 443 端口，并对外提供 HTTPS 服务。这里我们推荐使用 Nginx 进行端口映射。

```nginx
server {
  listen 443 ssl http2;
  listen [::]:443 ssl http2;
  server_name my-website.com www.my-website.com;
  
  ssl_certificate /path/to/certificate.pem;
  ssl_certificate_key /path/to/privkey.pem;
  ssl_session_cache shared:ssl:1m;
  ssl_session_timeout 10m;
  ssl_ciphers ECDHE-RSA-AES128-GCM-SHA256:ECDHE:ECDH:AES:HIGH:!NULL:!aNULL:!MD5:!ADH:!RC4;
  ssl_protocols TLSv1 TLSv1.1 TLSv1.2;
  ssl_prefer_server_ciphers on;

	location /credit-parking-demo {
		rewrite /credit-parking-demo/(.*) /$1 break;
		proxy_pass http://localhost:8080;
	}
}
```

```shell
nginx -s reload
```

### 测试

经过以上步骤，我们应该能从 `https://www.my-website.com/credit-parking-demo` （更换为您部署的地址）正常访问示例代码服务了，若页面显示“你好，微信支付分停车服务！”则代表我们已经部署成功，接下来就可以与前端联调并体验 demo 了。

