package dao

import "sync"

var (
	serviceStatusMap = sync.Map{} // string -> bool
	parkingIDMap     = sync.Map{} // string -> string
	outParkingNoMap  = sync.Map{} // string -> string
)

// GetServiceStatus 获取用户服务开通状态
func GetServiceStatus(plateNumber string) bool {
	if status, ok := serviceStatusMap.Load(plateNumber); ok {
		if status.(bool) {
			return true
		}
	}
	return false
}

// SaveServiceStatus 新增或更新用户服务开通状态
func SaveServiceStatus(plateNumber string, status bool) {
	serviceStatusMap.Store(plateNumber, status)
}

// GetParkingID 获取用户停车 ID
func GetParkingID(plateNumber string) string {
	if parkingID, ok := parkingIDMap.Load(plateNumber); ok {
		return parkingID.(string)
	}
	return ""
}

// SaveParkingID 新增或更新用户停车 ID
func SaveParkingID(plateNumber string, parkingID string) {
	parkingIDMap.Store(plateNumber, parkingID)
}

// RemoveParkingID 删除停车 ID
func RemoveParkingID(plateNumber string) {
	parkingIDMap.Delete(plateNumber)
}

// GetParkingStatus 获取用户停车状态
func GetParkingStatus(plateNumber string) bool {
	return GetParkingID(plateNumber) != ""
}

// GetOutParkingNo 获取商户方停车 ID
func GetOutParkingNo(plateNumber string) string {
	if outParkingNo, ok := outParkingNoMap.Load(plateNumber); ok {
		return outParkingNo.(string)
	}
	return ""
}

// SaveOutParkingNo 保存商户方停车 ID
func SaveOutParkingNo(plateNumber string, outParkingNo string) {
	outParkingNoMap.Store(plateNumber, outParkingNo)
}

// RemoveOutParkingNo 删除商户方停车 ID
func RemoveOutParkingNo(plateNumber string) {
	outParkingNoMap.Delete(plateNumber)
}
