package handler

import (
	"encoding/json"
	"fmt"
	"io/ioutil"
	"log"
	"net/http"
	"os"

	"github.com/pkg/errors"
	"tencent.com/wxp/credit-parking-demo/model"
	"tencent.com/wxp/credit-parking-demo/util"
)

// HandleLoginRequest 处理登录相关请求
func HandleLoginRequest(w http.ResponseWriter, r *http.Request) {
	if r.Method == http.MethodPost {
		handleLogin(w, r)
	} else {
		// 其他情况返回 405 Method Not Allowed 错误
		http.Error(w, http.StatusText(http.StatusMethodNotAllowed), http.StatusMethodNotAllowed)
	}
}

func handleLogin(w http.ResponseWriter, r *http.Request) {
	body, err := ioutil.ReadAll(r.Body)
	if err != nil {
		err = errors.Errorf("Fail to read request body: body=%v, err=%v", r.Body, err)
		log.Print(err.Error())
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	params := model.LoginParams{}
	if err = json.Unmarshal(body, &params); err != nil {
		err = errors.Errorf("Fail to unmarshal body: %v", err)
		log.Print(err.Error())
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	getOpenIDURL := fmt.Sprintf(
		"https://api.weixin.qq.com/sns/jscode2session?appid=%s&secret=%s&js_code=%s&grant_type=authorization_code",
		os.Getenv("WXPAY_MERCHANT_APP_ID"),
		os.Getenv("WXPAY_MERCHANT_APP_SECRET"),
		params.Code,
	)

	rawResp, err := http.Get(getOpenIDURL)
	if err != nil {
		err = errors.Errorf("Fail to get open id: %v", err)
		log.Print(err.Error())
		http.Error(w, err.Error(), http.StatusInternalServerError)
		return
	}

	respBody, err := ioutil.ReadAll(rawResp.Body)
	if err != nil {
		err = errors.Errorf("Fail to read from resp body: %v", err)
		log.Print(err.Error())
		http.Error(w, err.Error(), http.StatusInternalServerError)
		return
	}

	log.Printf("Resp body: %s", string(respBody))

	resp := model.GetOpenIDResponse{}
	if err = json.Unmarshal(respBody, &resp); err != nil {
		err = errors.Errorf("Fail to unmarshal from resp body: %v", err)
		log.Print(err.Error())
		http.Error(w, err.Error(), http.StatusInternalServerError)
		return
	}

	util.WriteJSON(w, struct {
		OpenID string `json:"openid"`
	}{resp.OpenID})

}
