package model

import "time"

// LoginParams 用户小程序登录请求参数
type LoginParams struct {
	Code string `json:"code"`
}

// GetOpenIDResponse 获取用户 openid 响应结果
type GetOpenIDResponse struct {
	SessionKey string `json:"session_key"`
	OpenID     string `json:"openid"`
}

// ParkingParams 用户入场或离场的请求参数
type ParkingParams struct {
	PlateNumber  string    `json:"plate_number"`
	PlateColor   string    `json:"plate_color"`
	ParkingName  string    `json:"parking_name"`
	StartTime    time.Time `json:"start_time"`
	FreeDuration int64     `json:"free_duration"`
}

// CreateParkingRequest 创建停车入场请求
type CreateParkingRequest struct {
	PlateNumber  string    `json:"plate_number"`
	PlateColor   string    `json:"plate_color"`
	ParkingName  string    `json:"parking_name"`
	StartTime    time.Time `json:"start_time"`
	FreeDuration int64     `json:"free_duration"`
	OutParkingNo string    `json:"out_parking_no"`
	NotifyURL    string    `json:"notify_url"`
}

// CreateParkingResponse 创建停车入场响应结果
type CreateParkingResponse struct {
	PlateNumber  string    `json:"plate_number"`
	PlateColor   string    `json:"plate_color"`
	ParkingName  string    `json:"parking_name"`
	StartTime    time.Time `json:"start_time"`
	FreeDuration int64     `json:"free_duration"`
	ParkingID    string    `json:"id"`
	State        string    `json:"state"`
	BlockReason  string    `json:"block_reason"`
}

// Amount 订单金额
type Amount struct {
	Total    int64  `json:"total"`
	Currency string `json:"currency"`
}

// ParkingInfo 停车信息
type ParkingInfo struct {
	ParkingID        string    `json:"parking_id"`
	PlateNumber      string    `json:"plate_number"`
	PlateColor       string    `json:"plate_color"`
	StartTime        time.Time `json:"start_time"`
	EndTime          time.Time `json:"end_time"`
	ParkingName      string    `json:"parking_name"`
	ChargingDuration int64     `json:"charging_duration"`
	DeviceID         string    `json:"device_id"`
}

// Payer 支付者信息
type Payer struct {
	OpenID    string `json:"open_id"`
	SubOpenID string `json:"sub_openid"`
}

// PromotionDetail 优惠信息
type PromotionDetail struct {
	CouponID            string `json:"coupon_id"`
	Name                string `json:"name"`
	Scope               string `json:"scope"`
	Type                string `json:"type"`
	StockID             string `json:"stock_id"`
	Amount              int64  `json:"amount"`
	WechatPayContribute int64  `json:"wechatpay_contribute"`
	MerchantContribute  int64  `json:"merchant_contribute"`
	OtherContribute     int64  `json:"other_contribute"`
	Currency            string `json:"currency"`
}

// CreateTransactionRequest 创建交易请求
type CreateTransactionRequest struct {
	AppID         string      `json:"appid"`
	Description   string      `json:"description"`
	Attach        string      `json:"attach"`
	OutTradeNo    string      `json:"out_trade_no"`
	TradeScene    string      `json:"trade_scene"`
	GoodsTag      string      `json:"goods_tag"`
	NotifyURL     string      `json:"notify_url"`
	ProfitSharing string      `json:"profit_sharing"`
	Amount        Amount      `json:"amount"`
	ParkingInfo   ParkingInfo `json:"parking_info"`
}

// CreateTransactionResponse 创建交易响应结果
type CreateTransactionResponse struct {
	AppID                 string            `json:"appid"`
	MerchantID            string            `json:"sp_mchid"`
	Description           string            `json:"description"`
	CreateTime            time.Time         `json:"create_time"`
	OutTradeNo            string            `json:"out_trade_no"`
	TransactionID         string            `json:"transaction_id"`
	TradeState            string            `json:"trade_state"`
	TradeStateDescription string            `json:"trade_state_description"`
	SuccessTime           time.Time         `json:"success_time"`
	BankType              string            `json:"bank_type"`
	UserRepaid            string            `json:"user_repaid"`
	Attach                string            `json:"attach"`
	TradeScene            string            `json:"trade_scene"`
	ParkingInfo           ParkingInfo       `json:"parking_info"`
	Payer                 Payer             `json:"payer"`
	Amount                Amount            `json:"amount"`
	PromotionDetail       []PromotionDetail `json:"promotion_detail"`
}

// ServiceStatusNotifyRequest 用户服务状态通知请求
type ServiceStatusNotifyRequest struct {
	MerchantID              string    `json:"sp_mchid"`
	ParkingID               string    `json:"parking_id"`
	OutParkingNo            string    `json:"out_parking_no"`
	PlateNumber             string    `json:"plate_number"`
	PlateColor              string    `json:"plate_color"`
	StartTime               time.Time `json:"start_time"`
	ParkingName             string    `json:"parking_name"`
	FreeDuration            int64     `json:"free_duration"`
	ParkingState            string    `json:"parking_state"`
	BlockedStateDescription string    `json:"blocked_state_description"`
	StateUpdateTime         string    `json:"state_update_time"`
}

// OrderStatusNotifyRequest 用户订单状态通知请求
type OrderStatusNotifyRequest struct {
	*CreateTransactionResponse
}
