package util

import (
	"bytes"
	"encoding/json"
	"io"
	"log"
	"math/rand"
	"net/http"
	"reflect"
	"strconv"
	"time"

	"tencent.com/wxp/credit-parking-demo/error"
)

func init() {
	rand.Seed(time.Now().Unix())
}

// GetRandIntStr 获取一个随机整数的字符串
func GetRandIntStr() string {
	return strconv.Itoa(rand.Int())
}

// WriteError 往 ResponseWriter 写入错误
func WriteError(w http.ResponseWriter, statusCode int, err interface{}) {
	if errBody, ok := err.(error.Error); ok {
		w.WriteHeader(statusCode)
		WriteJSON(w, errBody)
	} else if errStr, ok := err.(string); ok {
		http.Error(w, errStr, statusCode)
	} else {
		log.Printf("Invalid error type: %v", reflect.TypeOf(err))
	}
}

// WriteJSON 往 ResponseWriter 写入 JSON 数据
func WriteJSON(w http.ResponseWriter, v interface{}) {
	var buf bytes.Buffer
	if err := json.NewEncoder(&buf).Encode(v); err != nil {
		http.Error(w, err.Error(), http.StatusInternalServerError)
		log.Printf("Fail to encode data: %v", err)
		return
	}
	w.Header().Set("Content-Type", "application/json")
	if _, err := io.Copy(w, &buf); err != nil {
		log.Printf("Fail to copy io buf: %v", err)
		return
	}
}

// ToString 将对象转换成相应的字符串
func ToString(val interface{}) string {
	bytes, err := json.Marshal(val)
	if err != nil {
		return ""
	}
	return string(bytes)
}
